# Contributing to EQ Alert

:+1: :tada: First off, thanks for taking the time to contribute! :tada: :+1:

### How Can I Contribute?

#### Reporting Bugs
Explain the problem and include additional details to help maintainers reproduce the problem:
* **Use** a clear and descriptive title
* **Describe** exact steps to reproduce the problem
* **Provide** specific examples to demonstrate the steps
* **Explain** which behavior you expected to see

#### Suggested Enhancements
Enhancement suggestions are tracked as [GitHub issues](https://guides.github.com/features/issues/)
* **Use** a clear and descriptive title
* **Provide** a step-by-step description of the suggested enhancement with examples
* **Explain** why this enhancement would be useful

#### Pull Requests
* **Fork** the repo
* **Clone** the repo locally
* **Checkout** a new branch - `feature/my-branch-name`
* **Commit** your change [accordingly](https://github.com/torvalds/subsurface-for-dirk/blob/master/README#L92)
* **Push** your change to your remote fork
* Submit a **Pull request** against the master branch
